@@ -367,7 +367,7 @@ float PrayTime::calcJD(int year, int month, int day) {
                 float Fajr = computeTime(180 - calculationMethod.getFajrAngle(), t[0]);
                 float Sunrise = computeTime(180 - 0.833, t[1]);
                 float Dhuhr = computeMidDay(t[2]);
-                float Asr = computeAsr(1 + 0, t[3]);
+                float Asr = computeAsr(1 + asrJuristic, t[3]);
                 float Sunset = computeTime(0.833, t[4]);
                 float Maghrib = computeTime(calculationMethod.getMaghribParam(), t[5]);
                 float Isha = computeTime(calculationMethod.getIshaParam(), t[6]);
